.. exojax documentation master file, created by
   sphinx-quickstart on Mon Jan 11 14:38:51 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.
   
microjax
==================================
   
.. toctree::
   :maxdepth: 1
   :caption: API:

   microjax/microjax.rst

